@@ -49,7 +49,7 @@ GNeuron::~GNeuron()
 
 {
 
-    //UnLoad Matrices
+    //Unload Matrices
     delete [] InSlot;
     delete [] Weights;
 
@@ -169,7 +169,7 @@ void GNeuron::Enable(int NFType)
 
 
 
-//Set Input Data
+//Input Data
 void GNeuron::InData(int InputPin,float Data)
 
 {
@@ -195,6 +195,50 @@ float GNeuron::OutData()
 
 
 
+//Set Neuron Function Type
+void GNeuron::SetNFT(int NewNFT)
+
+{
+
+    NFT=NewNFT;
+
+}
+
+
+
+//Set Sum
+void GNeuron::SetSum(float NewSum)
+
+{
+
+    Summary=NewSum;
+
+}
+
+
+
+//Set Base
+void GNeuron::SetBase(float NewBase)
+
+{
+
+    Base=NewBase;
+
+}
+
+
+
+//Set Weights
+void GNeuron::SetWeights(int WPin,float Weight)
+
+{
+
+    Weights[WPin]=Weight;
+
+}
+
+
+
 //Get Neuron Function Type
 int GNeuron::GetNFT()
 
@@ -206,17 +250,6 @@ int GNeuron::GetNFT()
 
 
 
-//Get Base
-float GNeuron::GetBase()
-
-{
-
-    return Base;
-
-}
-
-
-
 //Get Sum
 float GNeuron::GetSum()
 
@@ -228,6 +261,17 @@ float GNeuron::GetSum()
 
 
 
+//Get Base
+float GNeuron::GetBase()
+
+{
+
+    return Base;
+
+}
+
+
+
 //Get Input Data
 float GNeuron::GetInData(int DIndex)
 
