@@ -38,7 +38,7 @@ void GNMS(int SimFunc)
     float NewData[MAX_PIN];	//New Data From Inputs GSocket
     float GMinData[MAX_PIN];	//Min Data Value Produced By G.A.N.N
     float GMaxData[MAX_PIN];	//Max Data Value Produced By G.A.N.N
-    float TErr;			//Threshold Error (%)
+    float AccErr;		//Acceptable Error (%)
     float GErr;			//G.A.N.N Error (%)
     float Tmp;			//Temp Values
     
@@ -61,8 +61,8 @@ void GNMS(int SimFunc)
     Inputs=InSocket.GetPins();
     Outputs=OutSocket.GetPins();
     
-    //Get Threshold Error Statistics
-    TErr=100.0-Threshold;
+    //Get Acceptable Error
+    AccErr=100.0-Threshold;
     
     //Fill NData With Inputs GSocket Data (Only For Uniform Checks)
     for (i=0;i<Inputs;i++)
@@ -248,11 +248,11 @@ void GNMS(int SimFunc)
             GErr=GErrStat(NewData,GMinData,GMaxData,ECT);
             
             //Check Error Statistics
-            if (GErr<=TErr)
+            if (GErr<=AccErr)
             
             {
             
-                //Save This G.A.N.N To The GKDB
+                //Save This G.A.N.N To GKDB
                 GSaveData(GANN);
                 
                 //Print Outputs GSocket
@@ -322,12 +322,19 @@ void GNMS(int SimFunc)
     
     {
     
+        //Run GRMC For User Interaction
+        GRMC();
+        
+        //Start Simulation
         
     
     }
     
-    //UnLoad G.A.N.N From Memory (G.A.N.N Matrix)
+    //Unload G.A.N.N From Memory (G.A.N.N Matrix)
     delete [] GANN;
+    
+    //Clean Up
+    system("rm GIOD GMap");
 
 }
 
