@@ -42,13 +42,19 @@ void GSaveData(GNeuron *GMatrix)
     
     {
     
-        fprintf(FileToSave,"%i\n",i+1);
-        fprintf(FileToSave,"%i\n",GMatrix[i].GetInData(i));
-        fprintf(FileToSave,"%i\n",GMatrix[i].GetWeights(i));
+        for (j=0;j<Inputs;j++)
+        
+        {
+        
+            fprintf(FileToSave,"%f\n",GMatrix[i].GetInData(j));
+            fprintf(FileToSave,"%f\n",GMatrix[i].GetWeights(j));
+        
+        }
+        
         fprintf(FileToSave,"%i\n",GMatrix[i].GetNFT());
-        fprintf(FileToSave,"%f\n",GMatrix[i].GetBase());
         fprintf(FileToSave,"%f\n",GMatrix[i].GetSum());
-        fprintf(FileToSave,"%f\n",GMatrix[i].OutData());
+        fprintf(FileToSave,"%f\n",GMatrix[i].GetBase());
+        fprintf(FileToSave,"%f\n",GMatrix[i].Mod);
     
     }
     
